@@ -4,6 +4,7 @@ The Netbios module performs netbios-related
 enumeration tasks.
 
 @author: Steve Coward (steve<at>sugarstack.io)
+@author: Erik Dominguez (maleus<at>overflowsecurity.com)
 @version: 1.0
 """
 import os
@@ -14,9 +15,9 @@ from ..generic_service import GenericService
 
 class NbtEnumeration(GenericService, ProcessManager):
     LIB_PATH = os.path.dirname(os.path.realpath(__file__))
-    SERVICE_DEFINITION = 'port:445'
+    SERVICE_DEFINITION = 'port:139,445'
     PROCESSES = [
-        'enum4linux -a %(host)s > %(output_dir)s/%(host)s-nbt-enum4linux.txt', ]
+	'enum4linux -a %(host)s > %(output_dir)s/%(host)s-nbt-enum4linux.txt',]
 
     def scan(self, directory, service_parameters):
         """Iterates over PROCESSES and builds
